==> index_now_commerce-1.0.0.tar.gz: index_now_commerce/src/Alter/Form/ModuleSettingsFormAlter.php <==
<?php

namespace Drupal\index_now_commerce\Alter\Form;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\DependencyInjection\ContainerInjectionInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Alter index_now_settings form.
 */
class ModuleSettingsFormAlter implements ContainerInjectionInterface {

  use StringTranslationTrait;

  /**
   * The index_now settings.
   *
   * @var Drupal\Core\Config\ImmutableConfig
   */
  protected $config;

  /**
   * Existing commerce products types.
   *
   * @var array
   */
  protected $productsTypes;

  /**
   * Class constructor.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The config factory.
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The entity type manager.
   */
  public function __construct(
    ConfigFactoryInterface $config_factory,
    EntityTypeManagerInterface $entity_type_manager
  ) {
    $this->config = $config_factory->get('index_now.settings');
    $this->productsTypes = $entity_type_manager
      ->getStorage('commerce_product_type')
      ->loadMultiple();
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('config.factory'),
      $container->get('entity_type.manager')
    );
  }

  /**
   * Alter the form.
   *
   * @param array $form
   *   The renderable form array we want to alter.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The form state.
   */
  public function alterForm(array &$form, FormStateInterface $form_state) {
    if (!isset($form['tabs'])) {
      $form['tabs'] = [
        '#type' => 'vertical_tabs',
        '#title' => $this->t("Restrict use"),
      ];
    }

    $form['commerce_product'] = [
      '#type' => 'details',
      '#title' => $this->t("Products types"),
      '#group' => 'tabs',
    ];

    $products_types = [];
    /** @var \Drupal\commerce_product\Entity\ProductType $product_type */
    foreach ($this->productsTypes as $machine_name => $product_type) {
      $products_types[$machine_name] = $product_type->label();
    }

    $form['commerce_product']['exclude_commerce_product_types'] = [
      '#type' => 'checkboxes',
      '#options' => $products_types,
      '#title' => $this->t("Exclude products types"),
      '#description' => $this->t("Selected products types won't use Index now"),
      '#default_value' => $this->config
        ->get('exclude_commerce_product_types') ?? [],
    ];

    $form['#submit'][] = [static::class, 'saveCommerceConfig'];
  }

  /**
   * Save commerce config.
   *
   * @param array $form
   *   An associative array containing the structure of the form.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The current state of the form.
   */
  public static function saveCommerceConfig(array &$form, FormStateInterface $form_state): void {
    $config = \Drupal::service('config.factory')->getEditable('index_now.settings');
    $config->set('exclude_commerce_product_types', $form_state->getValue('exclude_commerce_product_types'));
    $config->save();
  }

}

==> index_now_commerce-1.1.0.tar.gz: index_now_commerce/src/Alter/Form/ModuleSettingsFormAlter.php <==
<?php

namespace Drupal\index_now_commerce\Alter\Form;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\DependencyInjection\ContainerInjectionInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Alter index_now_settings form.
 */
class ModuleSettingsFormAlter implements ContainerInjectionInterface {

  use StringTranslationTrait;

  /**
   * The index_now settings.
   *
   * @var Drupal\Core\Config\ImmutableConfig
   */
  protected $config;

  /**
   * Existing commerce products types.
   *
   * @var array
   */
  protected $productsTypes;

  /**
   * Class constructor.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $configFactory
   *   The config factory.
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entityTypeManager
   *   The entity type manager.
   */
  public function __construct(
    protected ConfigFactoryInterface $configFactory,
    protected EntityTypeManagerInterface $entityTypeManager
  ) {
    $this->config = $configFactory->get('index_now.settings');
    $this->productsTypes = $entityTypeManager
      ->getStorage('commerce_product_type')
      ->loadMultiple();
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('config.factory'),
      $container->get('entity_type.manager')
    );
  }

  /**
   * Alter the form.
   *
   * @param array $form
   *   The renderable form array we want to alter.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The form state.
   */
  public function alterForm(array &$form, FormStateInterface $form_state) {
    if (!isset($form['tabs'])) {
      $form['tabs'] = [
        '#type' => 'vertical_tabs',
        '#title' => $this->t("Restrict use"),
      ];
    }

    $form['commerce_product'] = [
      '#type' => 'details',
      '#title' => $this->t("Products types"),
      '#group' => 'tabs',
    ];

    $products_types = [];
    /** @var \Drupal\commerce_product\Entity\ProductType $product_type */
    foreach ($this->productsTypes as $machine_name => $product_type) {
      $products_types[$machine_name] = $product_type->label();
    }

    $form['commerce_product']['exclude_commerce_product_types'] = [
      '#type' => 'checkboxes',
      '#options' => $products_types,
      '#title' => $this->t("Exclude products types"),
      '#description' => $this->t("Selected products types won't use Index now"),
      '#default_value' => $this->config
        ->get('exclude_commerce_product_types') ?? [],
    ];

    $form['#submit'][] = [static::class, 'saveCommerceConfig'];
  }

  /**
   * Save commerce config.
   *
   * @param array $form
   *   An associative array containing the structure of the form.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The current state of the form.
   */
  public static function saveCommerceConfig(array &$form, FormStateInterface $form_state): void {
    $config = \Drupal::service('config.factory')->getEditable('index_now.settings');
    $config->set('exclude_commerce_product_types', $form_state->getValue('exclude_commerce_product_types'));
    $config->save();
  }

}
